searchData={"items":[{"type":"module","title":"ExAws.CloudTrail","doc":"Implementation of AWS CloudTrail API","ref":"ExAws.CloudTrail.html"},{"type":"function","title":"ExAws.CloudTrail.add_tags/2","doc":"Adds one or more tags to a trail, up to a limit of 50\n\n  Tags must be unique per trail. Overwrites an existing tag's value\n  when a new value is specified for an existing tag key. If you\n  specify a key without a value, the tag will be created with the\n  specified key and a value of null. You can tag a trail that applies\n  to all regions only from the region in which the trail was\n  created (that is, from its home region).","ref":"ExAws.CloudTrail.html#add_tags/2"},{"type":"function","title":"Parameters - ExAws.CloudTrail.add_tags/2","doc":"* resource_id (string) - Required. Specifies the ARN of the trail to which one\n  or more tags will be added. The format of a trail ARN is:\n  `arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail`\n\n  * tags_list (List) - Contains a list of CloudTrail tags, up to a limit of 50. Each\n  tag must have a key. The key must be must be no longer than 128 Unicode characters.\n  The key must be unique for the resource to which it applies. The tag value must\n  be no longer than 256 Unicode characters. Each element in the tags_list is supplied as:\n  `[%{key: \"Key\", value: \"Value\"}]`","ref":"ExAws.CloudTrail.html#add_tags/2-parameters"},{"type":"function","title":"ExAws.CloudTrail.create_trail/3","doc":"Creates a trail that specifies the settings for delivery of log data to\n  an Amazon S3 bucket\n\n  A maximum of five trails can exist in a region, irrespective of the\n  region in which they were created.","ref":"ExAws.CloudTrail.html#create_trail/3"},{"type":"function","title":"Parameters - ExAws.CloudTrail.create_trail/3","doc":"* name (string) - Required. Specifies the name of the trail. The name must meet the\n  following requirements:\n\n    * Contains only ASCII letters (a-z, A-Z), numbers (0-9), periods (.),\n    underscores (_), or dashes (-)\n    * Start with a letter or number, and end with a letter or number\n    * Be between 3 and 128 characters\n    * Have no adjacent periods, underscores or dashes. Names like\n    my-_namespace and my--namespace are invalid.\n    * Not be in IP address format (for example, 192.168.5.4)\n\n * s3_bucket_name (string) - Required. Specifies the name of the Amazon S3 bucket designated\n for publishing log files. See [Amazon S3 Bucket Naming Requirements](https://amzn.to/2RkmbzH).\n\n * cloud_watch_logs_log_group_arn (string) - Specifies a log group name using an Amazon Resource\n Name (ARN), a unique identifier that represents the log group to which CloudTrail logs\n will be delivered. Not required unless you also supply cloud_watch_logs_role_arn.\n\n * cloud_watch_logs_role_arn (string) - Specifies the role for the CloudWatch Logs endpoint to\n assume to write to a user's log group\n\n * enable_log_file_validation (boolean) - Specifies whether log file integrity validation is enabled.\n The default is false.\n\n * include_global_service_events (boolean) - Specifies whether the trail is publishing events from\n global services such as IAM to the log files\n\n * is_multi_region_trail (boolean) - Specifies whether the trail is created in the current\n region or in all regions. The default is false.\n\n * is_organization_trail (boolean) - Specifies whether the trail is created for all accounts\n in an organization in AWS Organizations, or only for the current AWS account. The default is\n false, and cannot be true unless the call is made on behalf of an AWS account that is the\n master account for an organization in AWS Organizations.\n\n * kms_key_id (string) - Specifies the KMS key ID to use to encrypt the logs delivered by\n CloudTrail. The value can be an alias name prefixed by \"alias/\", a fully specified ARN to\n an alias, a fully specified ARN to a key, or a globally unique identifier.\n\n * sns_topic_name (string) - Specifies the name of the Amazon SNS topic defined for notification\n of log file delivery. The maximum length is 256 characters.","ref":"ExAws.CloudTrail.html#create_trail/3-parameters"},{"type":"function","title":"ExAws.CloudTrail.delete_trail/1","doc":"Deletes a trail\n\n  This operation must be called from the region in which the trail was\n  created. delete_trail cannot be called on the shadow trails (replicated\n  trails in other regions) of a trail that is enabled in all regions.","ref":"ExAws.CloudTrail.html#delete_trail/1"},{"type":"function","title":"Parameters - ExAws.CloudTrail.delete_trail/1","doc":"* name (string) - Required. Specifies the name or the CloudTrail ARN of\n  the trail to be deleted. The format of a trail ARN is:\n  `arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail`","ref":"ExAws.CloudTrail.html#delete_trail/1-parameters"},{"type":"function","title":"ExAws.CloudTrail.describe_trails/1","doc":"Retrieves settings for the trail associated with the current region for\n  your account","ref":"ExAws.CloudTrail.html#describe_trails/1"},{"type":"function","title":"Parameters - ExAws.CloudTrail.describe_trails/1","doc":"* include_shadow_trails (boolean) - Specifies whether to include shadow\n  trails in the response. A shadow trail is the replication in a region of\n  a trail that was created in a different region, or in the case of an\n  organization trail, the replication of an organization trail in member\n  accounts. If you do not include shadow trails, organization trails in a\n  member account and region replication trails will not be returned.\n  The default is true.\n\n  * trail_name_list (list of string) - Specifies a list of trail names,\n  trail ARNs, or both, of the trails to describe.","ref":"ExAws.CloudTrail.html#describe_trails/1-parameters"},{"type":"function","title":"ExAws.CloudTrail.get_event_selectors/1","doc":"Describes the settings for the event selectors that you configured for\n  your trail\n\n  The information returned for your event selectors includes the following:\n\n  * If your event selector includes read-only events, write-only events,\n  or all events. This applies to both management events and data events.\n\n  * If your event selector includes management events.\n\n  * If your event selector includes data events, the Amazon S3 objects or\n  AWS Lambda functions that you are logging for data events.\n\n  For more information, see\n  [Logging Data and Management Events for Trails](https://amzn.to/2DGkWY9)\n  in the AWS CloudTrail User Guide.","ref":"ExAws.CloudTrail.html#get_event_selectors/1"},{"type":"function","title":"Parameters - ExAws.CloudTrail.get_event_selectors/1","doc":"* trail_name (string) - Required. Specifies the name of the trail or trail ARN.\nIf you specify a trail name, the string must meet the following requirements:\n\n  * Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)\n  * Start with a letter or number, and end with a letter or number\n  * Be between 3 and 128 characters\n  * Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are not valid.\n  * Not be in IP address format (for example, 192.168.5.4)\n\n  * If you specify a trail ARN, it must be in the format:\n  `arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail`","ref":"ExAws.CloudTrail.html#get_event_selectors/1-parameters"},{"type":"function","title":"ExAws.CloudTrail.get_trail_status/1","doc":"Returns a JSON-formatted list of information about the specified trail\n\n  Fields include information on delivery errors, Amazon SNS and Amazon S3 errors,\n  and start and stop logging times for each trail. This operation returns trail\n  status from a single region. To return trail status from all regions, you must\n  call the operation on each region.","ref":"ExAws.CloudTrail.html#get_trail_status/1"},{"type":"function","title":"Parameters - ExAws.CloudTrail.get_trail_status/1","doc":"* Name (string) - Required. Specifies the name or the CloudTrail ARN of the trail\n  for which you are requesting status. To get the status of a shadow trail (a\n  replication of the trail in another region), you must specify its ARN.\n  The format of a trail ARN is:\n\n      `arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail`","ref":"ExAws.CloudTrail.html#get_trail_status/1-parameters"},{"type":"function","title":"ExAws.CloudTrail.list_public_keys/1","doc":"Returns all public keys whose private keys were used to sign the digest\n  files within the specified time range\n\n  The public key is needed to validate digest files that were signed with\n  its corresponding private key.","ref":"ExAws.CloudTrail.html#list_public_keys/1"},{"type":"function","title":"Note - ExAws.CloudTrail.list_public_keys/1","doc":"CloudTrail uses different private/public key pairs per region. Each digest\n  file is signed with a private key unique to its region. Therefore, when you\n  validate a digest file from a particular region, you must look in the same\n  region for its corresponding public key.","ref":"ExAws.CloudTrail.html#list_public_keys/1-note"},{"type":"function","title":"Parameters - ExAws.CloudTrail.list_public_keys/1","doc":"* end_time - Optionally specifies, in UTC, the end of the time range to\n  look up public keys for CloudTrail digest files. If not specified, the\n  current time is used. Passed in milliseconds since epoch.\n\n  * next_token (string) - Reserved for future use\n\n  * start_time - Optionally specifies, in UTC, the start of the time range\n  to look up public keys for CloudTrail digest files. If not specified,\n  the current time is used, and the current public key is returned.\n  Passed in milliseconds since epoch.","ref":"ExAws.CloudTrail.html#list_public_keys/1-parameters"},{"type":"function","title":"ExAws.CloudTrail.list_tags/2","doc":"Lists the tags for the trail in the current region","ref":"ExAws.CloudTrail.html#list_tags/2"},{"type":"function","title":"Parameters - ExAws.CloudTrail.list_tags/2","doc":"* resource_id_list (list) - Required. Specifies a list of trail ARNs whose tags\n  will be listed. The list has a limit of 20 ARNs.\n\n  * next_token (string) - Reserved for future use","ref":"ExAws.CloudTrail.html#list_tags/2-parameters"},{"type":"function","title":"ExAws.CloudTrail.lookup_events/1","doc":"Looks up management events captured by CloudTrail\n\n  Events for a region can be looked up in that region during the last\n  90 days. Lookup supports the following attributes:\n\n  * AWS access key\n  * Event ID\n  * Event name\n  * Event source\n  * Read only\n  * Resource name\n  * Resource type\n  * User name\n\n  All attributes are optional. The default number of results returned is\n  50, with a maximum of 50 possible. The response includes a token that you can\n  use to get the next page of results.","ref":"ExAws.CloudTrail.html#lookup_events/1"},{"type":"function","title":"Important - ExAws.CloudTrail.lookup_events/1","doc":"The rate of lookup requests is limited to one per second per account. If this\n  limit is exceeded, a throttling error occurs.","ref":"ExAws.CloudTrail.html#lookup_events/1-important"},{"type":"function","title":"Important - ExAws.CloudTrail.lookup_events/1","doc":"Events that occurred during the selected time range will not be available for\n  lookup if CloudTrail logging was not enabled when the events occurred.","ref":"ExAws.CloudTrail.html#lookup_events/1-important"},{"type":"function","title":"Parameters - ExAws.CloudTrail.lookup_events/1","doc":"* end_time - Specifies that only events that occur before or at the specified\n  time are returned. If the specified end time is before the specified start time,\n  an error is returned.\n\n  * lookup_attributes - Contains a list of lookup attributes. Currently the list\n  can contain only one item.\n\n  * max_results (integer) - The number of events to return. 1-50. The default is 50.\n\n  * next_token (string) - The token to use to get the next page of results after a\n  previous API call. This token must be passed in with the same parameters that were\n  specified in the the original call. For example, if the original call specified an\n  AttributeKey of 'Username' with a value of 'root', the call with next_token should\n  include those same parameters.\n\n  * start_time - Specifies that only events that occur after or at the specified time\n  are returned. If the specified start time is after the specified end time, an error\n  is returned.","ref":"ExAws.CloudTrail.html#lookup_events/1-parameters"},{"type":"function","title":"ExAws.CloudTrail.put_event_selectors/2","doc":"Configures an event selector for your trail\n\n  Use event selectors to further specify the management and data event\n  settings for your trail. By default, trails created without specific event\n  selectors will be configured to log all read and write management events,\n  and no data events.\n\n  When an event occurs in your account, CloudTrail evaluates the event selectors\n  in all trails. For each trail, if the event matches any event selector, the\n  trail processes and logs the event. If the event doesn't match any event\n  selector, the trail doesn't log the event.","ref":"ExAws.CloudTrail.html#put_event_selectors/2"},{"type":"function","title":"Example - ExAws.CloudTrail.put_event_selectors/2","doc":"1. You create an event selector for a trail and specify that you want write-only events.\n  2. The EC2 GetConsoleOutput and RunInstances API operations occur in your account.\n  3. CloudTrail evaluates whether the events match your event selectors.\n  4.  The RunInstances is a write-only event and it matches your event selector. The\n  trail logs the event.\n  5. The GetConsoleOutput is a read-only event but it doesn't match your event selector.\n  The trail doesn't log the event.\n\n  The `put_event_selectors/2` operation must be called from the region in which the trail\n  was created; otherwise, an InvalidHomeRegionException is thrown.\n\n  You can configure up to five event selectors for each trail. For more information,\n  see [Logging Data and Management Events for Trails](https://amzn.to/2DGkWY9) and\n  [Limits in AWS CloudTrail](https://amzn.to/2H39FVw) in the AWS CloudTrail User Guide.","ref":"ExAws.CloudTrail.html#put_event_selectors/2-example"},{"type":"function","title":"Parameters - ExAws.CloudTrail.put_event_selectors/2","doc":"* trail_name (string) - Required. Specifies the name of the trail or trail ARN.\n\n  * event_selectors (list) - Specifies the settings for your event selectors.\n  You can configure up to five event selectors for a trail. Format is:\n\n        ```\n        selectors = [\n          [\n            data_resources: [\n              %{\n                type: \"AWS::Lambda::Function\",\n                values: [lambda_func1, lambda_func2]\n              }\n            ],\n            read_write_type: \"All\"\n          ]\n        ]\n        ```","ref":"ExAws.CloudTrail.html#put_event_selectors/2-parameters"},{"type":"function","title":"ExAws.CloudTrail.remove_tags/2","doc":"Removes the specified tags from a trail","ref":"ExAws.CloudTrail.html#remove_tags/2"},{"type":"function","title":"Parameters - ExAws.CloudTrail.remove_tags/2","doc":"* resource_id (string) - Required. Specifies the ARN of the trail from which\n  tags should be removed.\n\n  * tags_list (list) - Specifies a list of tags to be removed. See `list_tags/2`","ref":"ExAws.CloudTrail.html#remove_tags/2-parameters"},{"type":"function","title":"ExAws.CloudTrail.start_logging/1","doc":"Starts the recording of AWS API calls and log file delivery for a trail\n\n  For a trail that is enabled in all regions, this operation must be called from\n  the region in which the trail was created. This operation cannot be called on\n  the shadow trails (replicated trails in other regions) of a trail that is\n  enabled in all regions","ref":"ExAws.CloudTrail.html#start_logging/1"},{"type":"function","title":"Parameters - ExAws.CloudTrail.start_logging/1","doc":"* name (string) - Required. Specifies the name or the CloudTrail ARN of the\n  trail for which CloudTrail will log AWS API calls","ref":"ExAws.CloudTrail.html#start_logging/1-parameters"},{"type":"function","title":"ExAws.CloudTrail.stop_logging/1","doc":"Suspends the recording of AWS API calls and log file delivery for the specified trail\n\n  Under most circumstances, there is no need to use this action. You can update a trail\n  without stopping it first. This action is the only way to stop recording. For a trail\n  enabled in all regions, this operation must be called from the region in which the\n  trail was created, or an InvalidHomeRegionException will occur. This operation cannot\n  be called on the shadow trails (replicated trails in other regions) of a trail\n  enabled in all regions.","ref":"ExAws.CloudTrail.html#stop_logging/1"},{"type":"function","title":"Parameters - ExAws.CloudTrail.stop_logging/1","doc":"* name (string) - Required. Specifies the name or the CloudTrail ARN of the\n  trail for which CloudTrail will stop logging AWS API calls","ref":"ExAws.CloudTrail.html#stop_logging/1-parameters"},{"type":"function","title":"ExAws.CloudTrail.update_trail/2","doc":"Updates the settings that specify delivery of log files\n\n  Changes to a trail do not require stopping the CloudTrail service. Use this action to\n  designate an existing bucket for log delivery. If the existing bucket has previously\n  been a target for CloudTrail log files, an IAM policy exists for the bucket. update_trail\n  must be called from the region in which the trail was created; otherwise, an\n  InvalidHomeRegionException is thrown.","ref":"ExAws.CloudTrail.html#update_trail/2"},{"type":"function","title":"Parameters - ExAws.CloudTrail.update_trail/2","doc":"* name (string) - Required. Specifies the name of the trail or trail ARN (see `create_trail/2`)\n\n  * cloud_watch_logs_log_group_arn (string) - Specifies a log group name using an Amazon Resource\n  Name (ARN), a unique identifier that represents the log group to which CloudTrail logs\n  will be delivered. Not required unless you also supply cloud_watch_logs_role_arn.\n\n  * cloud_watch_logs_role_arn (string) - Specifies the role for the CloudWatch Logs endpoint to\n  assume to write to a user's log group\n\n  * enable_log_file_validation (boolean) - Specifies whether log file integrity validation is enabled.\n  The default is false.\n\n  * include_global_service_events (boolean) - Specifies whether the trail is publishing events from\n  global services such as IAM to the log files\n\n  * is_multi_region_trail (boolean) - Specifies whether the trail is created in the current\n  region or in all regions. The default is false.\n\n  * is_organization_trail (boolean) - Specifies whether the trail is created for all accounts\n  in an organization in AWS Organizations, or only for the current AWS account. The default is\n  false, and cannot be true unless the call is made on behalf of an AWS account that is the\n  master account for an organization in AWS Organizations.\n\n  * kms_key_id (string) - Specifies the KMS key ID to use to encrypt the logs delivered by\n  CloudTrail. The value can be an alias name prefixed by \"alias/\", a fully specified ARN to\n  an alias, a fully specified ARN to a key, or a globally unique identifier.\n\n  * sns_topic_name (string) - Specifies the name of the Amazon SNS topic defined for notification\n  of log file delivery. The maximum length is 256 characters.\n\n  * s3_bucket_name (string) - Specifies the name of the Amazon S3 bucket designated\n  for publishing log files. See [Amazon S3 Bucket Naming Requirements](https://amzn.to/2RkmbzH).\n\n  * s3_key_prefix (string) - Specifies the Amazon S3 key prefix that comes after the name\n  of the bucket you have designated for log file delivery. For more information, see\n  [Finding Your CloudTrail Log Files](https://amzn.to/2TjVdd9). The maximum length is 200 characters.","ref":"ExAws.CloudTrail.html#update_trail/2-parameters"},{"type":"type","title":"ExAws.CloudTrail.create_trail_opts/0","doc":"","ref":"ExAws.CloudTrail.html#t:create_trail_opts/0"},{"type":"type","title":"ExAws.CloudTrail.data_resource/0","doc":"","ref":"ExAws.CloudTrail.html#t:data_resource/0"},{"type":"type","title":"ExAws.CloudTrail.describe_trails_opts/0","doc":"","ref":"ExAws.CloudTrail.html#t:describe_trails_opts/0"},{"type":"type","title":"ExAws.CloudTrail.event_selector/0","doc":"","ref":"ExAws.CloudTrail.html#t:event_selector/0"},{"type":"type","title":"ExAws.CloudTrail.list_public_keys_opts/0","doc":"","ref":"ExAws.CloudTrail.html#t:list_public_keys_opts/0"},{"type":"type","title":"ExAws.CloudTrail.lookup_attribute/0","doc":"","ref":"ExAws.CloudTrail.html#t:lookup_attribute/0"},{"type":"type","title":"ExAws.CloudTrail.lookup_events_opts/0","doc":"","ref":"ExAws.CloudTrail.html#t:lookup_events_opts/0"},{"type":"type","title":"ExAws.CloudTrail.paging_options/0","doc":"","ref":"ExAws.CloudTrail.html#t:paging_options/0"},{"type":"type","title":"ExAws.CloudTrail.tag/0","doc":"","ref":"ExAws.CloudTrail.html#t:tag/0"},{"type":"type","title":"ExAws.CloudTrail.update_trail_opts/0","doc":"","ref":"ExAws.CloudTrail.html#t:update_trail_opts/0"},{"type":"module","title":"ExAws.CloudTrail.ListLookupEvents","doc":"Provide a helper for users of library to list all events\n\n  A common use case for the CloudTrail library is to lookup\n  events. The events may be paged (more than 50 results). This\n  module allows a caller to gather all the events rather than\n  handling paging themselves. The module uses Logger to output\n  warnings if an error occurs in AWS API calls.","ref":"ExAws.CloudTrail.ListLookupEvents.html"},{"type":"module","title":"Example Usage - ExAws.CloudTrail.ListLookupEvents","doc":"# Get all events on an EC2 instance\n    opts = [lookup_attributes: [attribute_key: \"ResourceName\", attribute_value: \"i-12345678\"]]\n    {:ok, events} = ListLookupEvents.list_lookup_events(opts, keys)","ref":"ExAws.CloudTrail.ListLookupEvents.html#module-example-usage"},{"type":"function","title":"ExAws.CloudTrail.ListLookupEvents.list_lookup_events/2","doc":"Return all CloudTrail events that match the opts criteria","ref":"ExAws.CloudTrail.ListLookupEvents.html#list_lookup_events/2"},{"type":"function","title":"Returns - ExAws.CloudTrail.ListLookupEvents.list_lookup_events/2","doc":"{:ok, [Event,...} on success or {:error, []} on failure","ref":"ExAws.CloudTrail.ListLookupEvents.html#list_lookup_events/2-returns"},{"type":"extras","title":"AWS CloudTrail API","doc":"# AWS CloudTrail API\n\nAWS CloudTrail Service module for [ex_aws](https://github.com/ex-aws/ex_aws).","ref":"readme.html"},{"type":"extras","title":"Installation - AWS CloudTrail API","doc":"The package can be installed by adding ex_aws_cloud_trail to your list of dependencies in mix.exs along with :ex_aws and your preferred JSON codec / http client. Example:\n\n```elixir\ndef deps do\n  [\n    {:ex_aws, \"~> 2.0\"},\n    {:ex_aws_cloud_trail, \"~> 2.0\"},\n    {:poison, \"~> 3.0\"},\n    {:hackney, \"~> 1.9\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - AWS CloudTrail API","doc":"* [ex_aws](https://hexdocs.pm/ex_aws)\n* [AWS CloudTrail API](https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/Welcome.html)\n* [Go API for CloudTrail](https://github.com/aws/aws-sdk-go/blob/master/models/apis/cloudtrail/2013-11-01/api-2.json)","ref":"readme.html#documentation"},{"type":"extras","title":"License - AWS CloudTrail API","doc":"[LICENSE](LICENSE)","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"v2.0.3\n\n* Fix: use Logger.warning instead of Logger.warn\n* Enhancement: Bring dependencies up to date\n* Enhancement: Show CHANGELOG and LICENSE in generated docs\n* Enhancement: Use Github Actions to compile/test code for various Elixir versions\n\nv2.0.2\n\n  * Fix: Change typespec for lookup_events and handle list of lists properly\n\nv2.0.1\n\n  * Enhancement: Added support for listing all lookup events with ListLookupEvents module.\n  * Fix: Remove sweet_xml from list of deps in mix.exs\n\nv2.0\n\n  * Initial version. Given 2.0 to align with ex_aws version.","ref":"changelog.html"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2019 Vonage, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}